const fs = require("fs");
const path = require("path");
const { promisify } = require("util");
const hashFile = require("./hash-file.js");
const pathExists = require("./path-exists");

const copyFile = promisify(fs.copyFile);
const makeDir = promisify(fs.mkdir);

module.exports = dir => async file => {
	const file_path = path.join(dir, file);
	if (!(await pathExists(file_path))) {
		console.error(`Could not load asset: '${file_path}'`.red);
		return "";
	}
	const out_dir = "public/assets/";
	if (!(await pathExists(out_dir))) {
		await makeDir(out_dir);
	}

	const file_extension = path.extname(file);
	const out_file_path = `${path.basename(
		file,
		file_extension
	)}-${await hashFile(file_path)}${file_extension}`;

	if (!(await pathExists(`${out_dir}${out_file_path}`))) {
		await copyFile(file_path, `${out_dir}${out_file_path}`);
	}
	return `/assets/${out_file_path}`;
};
