const fs = require("fs");
const path = require("path");
const sass = require("node-sass");
const { promisify } = require("util");

const sassRender = promisify(sass.render);

const js_scss_functions = require("./custom-node-sass-functions.js");
const custom_importer = require("./custom-node-sass-importer.js");

module.exports = async function build_style({ output_dir, scss_entrypoint }) {
	if (!fs.existsSync(output_dir)) {
		fs.mkdirSync(output_dir);
	}
	if (!fs.existsSync(path.resolve(output_dir, "styles"))) {
		fs.mkdirSync(path.resolve(output_dir, "styles"));
	}
	const outfile = path.resolve(output_dir, "styles", "style.css");
	const result = await sassRender({
		data: `@import "${scss_entrypoint}";`,
		sourceMap: true,
		functions: js_scss_functions,
		importer: custom_importer,
		outFile: outfile
	});
	fs.writeFileSync(outfile, result.css);
	fs.writeFileSync(outfile + ".map", result.map);
};
